pub enum MemoryPressureLevel {
Low,
Medium,
High,
Critical,
}Expand description
Severity level of memory pressure in a buffer pool.
Level is determined by the fraction of buffers that are currently in use:
| Level | In-use fraction |
|---|---|
| Low | < medium watermark |
| Medium | medium ≤ f < high |
| High | high ≤ f < critical |
| Critical | ≥ critical watermark |
Variants
Low
Less than the medium watermark is in use — pool is healthy.
Medium
Between medium and high watermarks.
High
Between high and critical watermarks.
Critical
At or above the critical watermark — pool nearly exhausted.