pub struct QueueStats {
pub total_pushed: u64,
pub total_popped: u64,
pub total_rejected: u64,
}Expand description
Lifetime throughput statistics for a WorkQueue.
Examples
use oximedia_core::work_queue::{WorkItem, WorkQueue};
let mut q: WorkQueue<()> = WorkQueue::new(16);
q.push(WorkItem::new((), 1)).expect("queue not full");
let _ = q.pop();
let stats = q.stats();
assert_eq!(stats.total_pushed, 1);
assert_eq!(stats.total_popped, 1);Fields
total_pushed: u64Cumulative number of items successfully pushed.
total_popped: u64Cumulative number of items removed via pop or pop_batch.
total_rejected: u64Cumulative number of push attempts that were rejected due to capacity.
Implementations